package com.fs.his.service;

import com.fs.his.domain.FsDoctorPatient;
import com.fs.his.param.TransferPatientParam;

import java.util.List;

/**
 * 患者信息Service接口
 *
 * @author yourname
 * @date 2026-04-28
 */
public interface IFsDoctorPatientService {
    /**
     * 查询患者信息
     */
    public FsDoctorPatient selectFsDoctorPatientById(Long id);

    /**
     * 查询患者信息列表
     */
    public List<FsDoctorPatient> selectFsDoctorPatientList(FsDoctorPatient fsDoctorPatient);

    /**
     * 新增患者信息
     */
    public int insertFsDoctorPatient(FsDoctorPatient fsDoctorPatient);

    /**
     * 修改患者信息
     */
    public int updateFsDoctorPatient(FsDoctorPatient fsDoctorPatient);

    /**
     * 删除患者信息
     */
    public int deleteFsDoctorPatientByIds(Long[] ids);

    /**
     * 查询医生的患者信息列表
     * */
    public List<FsDoctorPatient> selectFsDoctorPatientByDoctorId(Long doctorId);
    /**
     * 转交患者信息
     */
    public int transferPatient(TransferPatientParam param);
}